
;	Processor Type
;	==============

	LIST P=18F4520,r=hex,n=80,x=off,st=off
	errorlevel -302		; no bank warnings

	#include <P18F4520.INC>	

;******************************************************************************
; 
;	Configuration bits 
;	==================
  
; specified here are changes to the .inc file defaults

 CONFIG OSC=INTIO67, PWRT=ON, BOREN=OFF, WDT=OFF, MCLRE=OFF, LPT1OSC=OFF, PBADEN=OFF
 CONFIG LVP=OFF, XINST=OFF, DEBUG=OFF

;******************************************************************************
;
;	Variable definitions
;	====================

; These variables are only needed if low priority interrupts are used. 
; More variables may be needed to store other special function registers used
; in the interrupt routines.


;	Bank0 variables  0x000 to 0x07F access ram 0x80 to 0xFF bank15
;	to be used only for key 'system' variables	
;	(4550 bank0 to 0x05F only)				

	cblock  0x000


	WREG_TEMP	;variable used for context saving 
	STATUS_TEMP	;variable used for context saving
	BSR_TEMP	;variable used for context saving

	W_ISR_TEMP		; original isr variables
	STATUS_ISR_TEMP		
	PCL_ISR_TEMP
	FSR_ISR_TEMP
	PCLATH_ISR_TEM

	ENDC


;	Bank1 variables 0x100 to 0x1FF

	cblock	0x100		; BANK1			

	EECOUNT			; TESTING USE ONLY
	d1	
					; for 6 bit lcd		
					;EB last address entered   max FF
	endc				



;******************************************************************************
;
;	Reset vector
;	============

		ORG	0x0000

bootup	goto	Main		;go to start of main code

;******************************************************************************
;
;	High priority interrupt vector
;	==============================

; This code will start executing when a high priority interrupt occurs or
; when any interrupt occurs if interrupt priorities are not enabled.

		ORG	0x0008

		bra	HighInt		;go to high priority interrupt routine

;******************************************************************************
;
;	Low priority interrupt vector
;	=============================
 
; This code will start executing when a low priority interrupt occurs.
; This code can be removed if low priority interrupts are not used.

		ORG	0x0018

;		movff	STATUS,STATUS_TEMP	;save STATUS register
;		movff	WREG,WREG_TEMP		;save working register
;		movff	BSR,BSR_TEMP		;save BSR register

;	*** low priority interrupt code goes here ***


;		movff	BSR_TEMP,BSR		;restore BSR register
;		movff	WREG_TEMP,WREG		;restore working register
;		movff	STATUS_TEMP,STATUS	;restore STATUS register
		retfie

;******************************************************************************
;
;	High priority interrupt routine
;	===============================

; The high priority interrupt code is placed here to avoid conflicting with
; the low priority interrupt vector.


; Timer1 and Clock ; Timer1 and Clock Increment routines

HighInt		nop

isrtm1	btfsc PIR1,TMR1IF		; timer1 overflow int
	goto	tm1over		        ; timer1 has overflowed
	goto 	hisrend				; not tmr1 overflow - error - go back

tm1over bsf	TMR1H, 7			; preload for 1 sec overflow
	bcf	PIR1,TMR1IF				; reset timer1

	btg	PORTD,0

hisrend	retfie	FAST



;******************************************************************************
;******************************************************************************
;
;	Start of main program
;	=====================

; initialisation of system, clear RAM , setup i/o ports



Main	movlw	b'01100010'	; set internal osc to 4 mhz
		movwf	OSCCON



	movlb	D'1'			; define bank1, so it and bank 0/15 (access) 
								; can be addressed without banking
 		clrf 	INTCON			; clear interupts
 		clrf	STATUS			; reset to bank 0
 

 		clrf	FSR1H			; FSR routine to clear ram banks 0 -4 only
		clrf	FSR1L		





		 
			
ports	clrf	PORTA
		clrf	PORTC
		clrf	PORTD
		
		movlw	b'00001110'		; set portA as adc input bit 7 rjust
		movwf	ADCON1			; by loading value to adcon1 reg
		movlw	b'00111001'		; set trisa direction is input
		movwf	TRISA			; bit0 adc, bit1,2 DO, bit3,4,5 DI , bit7,6 DO

		movlw	b'00000011'		; set portB as low outputs
		movwf	TRISC

		movlw	b'00000000'		; set portC low outputs,  except rc2 DI
		movwf	TRISD
	


; ***************************************************************************
;
;	Start Timers
;	============





; Timer1 as the Real Time Clock  - Priority ISR driven

		movlw	0x80			; preload tmr1h with h80 to give 1sec
		movwf	TMR1H
		clrf	TMR1L
		movlw	b'00001111'		; configure for ext clock and Turn ON Timer1
		movwf	T1CON

		bsf		RCON,IPEN		; set interupt priority on

		clrf	IPR1			; clear IPR registers
		clrf	IPR2
		bsf		IPR1,TMR1IP		; set tmr1 as priority

		clrf	PIR2			; clear pir flag registers

		clrf	PIE1			; clear pir interrupt enable registers
		clrf	PIE2
		bsf		PIE1,TMR1IE		; turn on tmr1 Int Enabled

		clrf	INTCON			; clear intcons
		clrf	INTCON2			
		clrf	INTCON3
;		bsf		INTCON,GIEH		; enable global high prioriy on



loop;	GOTO loop

		btfsc PIR1,TMR1IF		; timer1 overflow int
		goto	tm1fin2	        ; timer1 has overflowed
		goto 	again				; not tmr1 overflow - error - go back

tm1fin2 bsf	TMR1H, 7			; preload for 1 sec overflow
		bcf	PIR1,TMR1IF				; reset timer1
		btg PORTD,1

again	goto	loop

		end